#=============================================================================
# RNA Configuration File
#=============================================================================
#
#=============================================================================
# Copyright (C) 2003	Ikki Ohmukai,		All rights reserved.
# Copyright (C) 2003	Masahiro Hamasaki,	All rights reserved.
#
#
# This file is part of RNA.
#
#	RNA is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	RNA is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with RNA; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#=============================================================================

package RNA::Config;
use strict;
#use lib qw(lib extlib);
use RNA;
use RNA::Hatena;
my $VERSION = $RNA::VERSION;

#-----------------------------------------------------------------------------
# 基本設定（必須）
# Basic Settings (require)
#-----------------------------------------------------------------------------

# あなたのお名前
# Your name
#my $antenna_owner = 'i2k';
my $antenna_owner = "your_name";

# RNAを設置するURI
# Base URI (directory) of your RNA
#my $base_uri = 'http://www-kasm.nii.ac.jp/~i2k/tmp/rna/';
my $base_uri = 'http://foo.bar.com/rna/';

#------------------------------------
# RNA機能拡張
# RNA Extensions
#------------------------------------

# バックグラウンド処理
#	アンテナの更新処理が完了する前にブラウザへのレスポンスを行います．
#	この設定を行うとブラウザからのリクエストと実際の更新の間に時間差が生じます．
#	※ UNIX系サーバでのみ設定可能です．
#	1: 使用する	0: 使用しない（アンテナの更新処理が完了するまでブラウザが待たされます）
# Background Processing (available in Unix-based server)
#	1: enable	0: disable
my $background_update = 1;

# リンク・TrackBackの抽出と表示
#	チェック対象の記事にリンクもしくはTrackBackが存在した場合に
#	これらのリンクを同時に表示します．
#	※ TrackBack抽出はMovableTypeで構築されたサイトのみが対象になります．
#	1: 使用する	0: 使用しない
# Link / TrackBack Tracing
#	1: enable	0: disable
my $link_trace = 1;
my $accumulative_link_trace = 1;

#------------------------------------
# 認証
# Authentication Settings
#------------------------------------

# 認証機能の有効/無効
# Activation
my $auth_configure_cgi = 1;	# 1: enable authentication	0: disable
# パスワードファイルの指定
# Password File
my $auth_file = '.rna-passwd';	# recommend to change...

#------------------------------------
# キャッシュ設定
# Cache Settings
#------------------------------------

# キャッシュの格納ディレクトリ
# Root Directory for Cache
my $cache_root = 'cache';

# サイトキャッシュ
# Site Cache
my $site_cache_dir = $cache_root . '/site';

# リンクキャッシュ
# Recent Link Cache
my $current_link_cache_dir = $cache_root . '/current_link';

# 保存用リンクキャッシュ
# Stored Link Cache
my $accumurative_link_cache_dir = $cache_root . '/link';

#------------------------------------
# プラグイン設定
# Plugin Settings
#------------------------------------

# プラグインの格納ディレクトリ
# Root Directory for Plugins
my $plugin_dir = 'plugins';

# プラグインのスクリプト名
# Main Script for Plugins
my $plugin_main_script = 'main.pl';

#------------------------------------
# 各ページのURI設定
# URI Settings
#------------------------------------

# トップページ
# Index Page
my $main_index_page  = 'index.html';
my $main_index_uri   = $base_uri . $main_index_page;
my $main_index_title = 'RNA::RSS Semblog Antenna';
my $main_index_description 
	= 'Version '. $VERSION . ' by semblog.org';

# メインCGI
# RNA Main CGI
my $update_cgi_uri = $base_uri . 'rna.cgi';

# サイト設定用CGI
# Configuration CGI
my $configure_cgi_uri = $base_uri . 'rna-conf.cgi';

# TrackBack PingインターフェイスCGI
# TrackBack Ping Interface CGI
my $ping_cgi_uri = $base_uri . 'rna-ping.cgi';

# XML-RPCインターフェイスCGI
# XML-RPC Interface CGI
my $xmlrpc_cgi_uri = $base_uri . 'rna-xmlrpc.cgi';

# OPML出力
# OPML Output
my $opml_output_uri = $base_uri . 'rna.cgi?mode=opml';

# キャッシュ管理用CGI
# Cache Management CGI
my $cache_cgi_uri = $base_uri . 'rna-cache.cgi';

# ClipインターフェイスCGI
# Clip Interface CGI
my $clip_cgi_uri = $base_uri . 'rna-clip.cgi';

# チェック結果(HTML/RSS)の格納ディレクトリ
# HTML/RSS Storage Directory
my $view_dir = 'rss';
my $rss_dir  = 'rss';

# RSSのXSLTスタイルシート
# XML Stylesheet for XSLT
my $stylesheet_for_rss = "$view_dir/rss01.xsl";

# 表示用CSSスタイルシート
# CSS Stylesheet
my $css_stylesheet = "styles-rna.css";

#------------------------------------
# RNAでチェックするサイトリストのRSS
# RSS Site List
#------------------------------------

my $site_list = 'site.rdf';
my $site_list_title = 'RNA::Site List';
my $site_list_description = 'RNAでチェックするサイトのリスト';
my $site_list_empty = '-';

#------------------------------------
# サイトのリスト（dc:date順にソート）
# RSS Updated Sites (ordered by dc:date)
#------------------------------------

my $recent_site_rss  = "$rss_dir/recent_site.rdf";
my $recent_site_html = "$view_dir/recent_site.html";
my $recent_site_xml  = "$view_dir/recent_site.xml";
my $recent_site_title       = 'RNA::Updated Sites';
my $recent_site_description = 'RNAでチェックするサイトのリスト（更新時間順）';

#------------------------------------
# 最新記事のリスト
# RSS Recent Entries (ordered by dc:date)
#------------------------------------

my $num_recent_article = 100;
my $recent_entry_rss  = "$rss_dir/recent_entry.rdf";
my $recent_entry_html = "$view_dir/recent_entry.html";
my $recent_entry_xml  = "$view_dir/recent_entry.xml";
my $recent_entry_title = 'RNA::Recent Entries';
my $recent_entry_description =
	'最新の' . $num_recent_article . 'エントリ';

#------------------------------------
# サイトごとの最新記事リスト
# RSS Recent Entries Classified by Sites
#------------------------------------

my $num_per_site = '5';
my $recent_site_entry_rss  = "$rss_dir/recent_site_entry.rdf";
my $recent_site_entry_html = "$view_dir/recent_site_entry.html";
#my $recent_site_entry_xml  = "$view_dir/recent_site_entry.xml";
my $recent_site_entry_title = 'RNA::Recent Sites/Entries';
my $recent_site_entry_description =
	'最新の'. $num_per_site . 'エントリ（サイトごと）';

#------------------------------------
# クリップ記事のリスト
# RSS Clipped Entries
#------------------------------------

my $clip_list_rss = "$rss_dir/clip.rdf";
my $clip_list_title = 'RNA::Clipped Entries';
my $clip_list_description = 'クリップされたエントリ一覧';
#my $clip_list_empty = '-';
my $clip_list_html = "$view_dir/clip.html";
#my $clip_list_xml = "$view_dir/clip.xml";
my $clip_form_data_item = q(
		<input type="hidden" name="action" value="Add" />
		<input type="hidden" name="target" value="update_clip_list" />
		<input type="hidden" name="select" value="<$RNAItemLink$>" />
		<input type="hidden" name="link" value="<$RNAItemLink$>" />
		<input type="hidden" name="title" value="<$RNAItemTitle$>" />
		<input type="hidden" name="description" value="<$RNAItemDescription$>"/>
		<input type="hidden" name="source" value="<$RNAItemSourceTitle$>"/>
		<input type="hidden" name="sourceURL" value="<$RNAItemSourceLink$>"/>
		<input type="hidden" name="date" value="<$RNAItemDate$>" />
		<input type="hidden" name="creator" value="<$RNAItemCreator$>" />
		<input type="hidden" name="subject" value="<$RNAItemSubject$>" />);
my $clip_form_data_content = q(
		<input type="hidden" name="action" value="Add" />
		<input type="hidden" name="target" value="update_clip_list" />
		<input type="hidden" name="select" value="<$RNAContentLink$>" />
		<input type="hidden" name="link" value="<$RNAContentLink$>" />
		<input type="hidden" name="title" value="<$RNAContentTitle$>" />
		<input type="hidden" name="description" value="<$RNAContentDescription$>"/>
		<input type="hidden" name="source" value="<$RNAContentSourceTitle$>"/>
		<input type="hidden" name="sourceURL" value="<$RNAContentSourceLink$>"/>
		<input type="hidden" name="date" value="<$RNAContentDate$>" />
		<input type="hidden" name="creator" value="<$RNAContentCreator$>" />
		<input type="hidden" name="subject" value="<$RNAContentSubject$>" />);

#------------------------------------
# その他の設定
# Other Settings
#------------------------------------

# HTTP によるアクセスのタイムアウト設定 [秒]
# Timeout of GET/HEAD/POST  [s]
my $timeout = 60;

# 文字コード
# Character Encoding
my $encoding = 'UTF-8';

# JavaScript
my $jscript = "jscript01.js";

# 言語
# Language
my $default_language = 'ja';

# はてなアンテナ連携モジュール
# RNA HATENA Antenna Module
my $hatena_flag = $RNA::Hatena::flag;

#------------------------------------
# デザインテンプレート
# Design Templates
#------------------------------------

my $template_dir = 'template';
my $main_index_template        = $template_dir . '/' . 'index_template';
my $recent_site_entry_template = $template_dir . '/' . 'rna_template';
my $recent_site_template       = $template_dir . '/' . 'recent_template';
my $recent_entry_template      = $recent_site_template;
my $config_template            = $template_dir . '/' . 'conf_template';
my $clip_template          = $template_dir . '/' . 'clip_template';
## for rna-clip
my $clip_config_template= $template_dir . '/' . 'conf_clip_template';
my $login_template             = $template_dir . '/' . 'login_template';

my %template_element = (
	RNAEncoding   => $encoding,
	RNAStyleSheet => $base_uri . $css_stylesheet,
	RNAJavaScript => $base_uri . $jscript,
	RNAUpdateCGIURI => $update_cgi_uri,
	RNATopURI     => $main_index_uri,
	RNAConfigureCGIURI => $configure_cgi_uri,
	RNAPingCGIURI => $ping_cgi_uri,
	RNAXMLRPCCGIURI => $xmlrpc_cgi_uri,

	## for rna-clip
	RNAClipRSSURI => $clip_list_rss,
	RNAClipHTMLURI => $clip_list_html,
	RNAClipCGIURI => $clip_cgi_uri, 
	__RNAClipFormDataContent__ => $clip_form_data_content,
	__RNAClipFormDataItem__ => $clip_form_data_item,

	RNAOPMLOutputURI => $opml_output_uri,
	RNACacheCGIURI => $cache_cgi_uri
);


#-----------------------------------------------------------------------------
# 
#-----------------------------------------------------------------------------

sub new {
    my $class = shift;
    my $self = {};
    
    bless $self, $class;
    
    $self->init(@_);
    
    return $self;
}

sub init {
    my $self = shift;
    my %hash = @_;

	$self->{Update}->{Background} = $background_update;

	$self->{LinkTrace} = $link_trace;
	$self->{AccumulativeLinkTrace} = $accumulative_link_trace;
	$self->{Cache} = {
		RootDirectory => $cache_root,
		SiteDirectory => $site_cache_dir,
		CurrentLinkDirectory => $current_link_cache_dir,
		AccumurativeLinkDirectory      => $accumurative_link_cache_dir
	};

	$self->{Owner}   = $antenna_owner;
	$self->{BaseURI} = $base_uri;

	$self->{Plugin} = {
		RootDirectory => $plugin_dir,
		MainScript    => $plugin_main_script
	};

	$self->{MainIndex} = {
		File  => $main_index_page,
		URI   => $main_index_uri,
		Title => $main_index_title,
		Description => $main_index_description
	};

	$self->{UpdateCGIURI}   = $update_cgi_uri;
	$self->{ConfigCGIURI}   = $configure_cgi_uri;
	$self->{PingCGIURI}     = $ping_cgi_uri;
	$self->{XMLRPCCGIURI}   = $xmlrpc_cgi_uri;
	$self->{CacheCGIURI}    = $cache_cgi_uri;
	$self->{ClipCGIURI}     = $clip_cgi_uri;

	$self->{ViewDirectory}  = $view_dir;
	$self->{RSSDirectory}       = $rss_dir;
	$self->{XSLTStyleSheet} = $stylesheet_for_rss;
	$self->{CSSStyleSheet}  = $css_stylesheet;

	$self->{SiteList} = {
		URI          => $self->{BaseURI} . $site_list ,
		File         => $site_list,
		Title        => $site_list_title,
		Description  => $site_list_description,
		EmptyContent => $site_list_empty
	};

	$self->{RecentSiteList} = {
		RSS     => $recent_site_rss,
		HTML    => $recent_site_html,
		XML     => $recent_site_xml,
		Title   => $recent_site_title,
		Description => $recent_site_description
	};

	$self->{RecentEntryList} = {
		Number => $num_recent_article,
		RSS    => $recent_entry_rss,
		HTML   => $recent_entry_html,
		XML    => $recent_entry_xml,
		Title  => $recent_entry_title,
		Description => $recent_entry_description
	};

	$self->{RecentSiteEntryList} = {
		NumberPerSite      => $num_per_site,
		RSS                => $recent_site_entry_rss,
		HTML               => $recent_site_entry_html,
		#XML                => $recent_site_entry_xml,
		Title              => $recent_site_entry_title,
		Description        => $recent_site_entry_description
	};

	## for rna-clip
	$self->{ClipList} = {
		RSS          => $clip_list_rss,
		HTML         => $clip_list_html,
		#XML          => $clip_list_xml,
		Title        => $clip_list_title,
		Description  => $clip_list_description,
		#EmptyContent => $clip_list_empty
	};

	# Authentication
	$self->{Authentication} = {
		PasswordFile => $auth_file,
		ConfigureCGI => $auth_configure_cgi
	};

	$self->{Timeout} = $timeout;
	$self->{Encoding} = $encoding;
	$self->{JavaScript} = $jscript;
	$self->{Language} = $default_language;
	$self->{HatenaFlag} = $hatena_flag;
	
	$self->{Template} = {
		Directory            => $template_dir,
		MainIndex            => $main_index_template,
		RecentSiteEntryList  => $recent_site_entry_template,
		RecentSiteList       => $recent_site_template,
		RecentEntryList      => $recent_entry_template,
		Configure            => $config_template,
		ClipList         => $clip_template, ## for rna-clip
		ClipConfigure    => $clip_config_template, ## for rna-clip
		Login            => $login_template,
		Element => \%template_element
	};
}

# $bool = $self->is_empty_content($str);
sub is_empty_content
{
	my $self = shift;
	my $str = shift;

	my $empty_content = $self->{SiteList}->{EmptyContent};
	
	return ($str eq $empty_content || !$str) ? 1 : 0;
}

# $empty_value = $self->empty_value;
sub empty_value
{
	my $self = shift;
	return $self->{SiteList}->{EmptyContent};
}

#=============================================================================
1;
