package RNA::Auth;
#=============================================================================
# Copyright (C) 2003           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# Authentication Module
# 
# 認証用モジュール
#=============================================================================

use strict;
use Carp;
use vars qw($VERSION);

$VERSION = '0.1';

my $default_encoding = 'UTF-8';
my $username_label = 'username';
my $passwd_label = 'passwd';
my $default_template = q(<html>
	<head>
		<title>RNA login</title>
		<meta http-equiv="Content-Type" content="text/html; charset=)
		. $default_encoding
		. q(" />
		<meta http-equiv="Content-Script-Type" content="text/javascript" />
		<script>
		<!--
		function set_cookie(<$RNAUserNameLabel$>, <$RNAPasswdLabel$>) {
			document.cookie
				 = "<$RNAUserNameLabel$>=" + escape(<$RNAUserNameLabel$>) + "; ";
			//	+ "path=/home/username/public_html/rna/; ";
			document.cookie
				 = "<$RNAPasswdLabel$>=" + escape(<$RNAPasswdLabel$>) + "; ";
		}
		// -->
		</script>
	</head>

	<body bgcolor="#eeeeee" text="#bbbbbb">
		<h2>RNA Login</h2><br>

		<form method="post" action="<$RNATransferURI$>" onSubmit="set_cookie(<$RNAUserNameLabel$>.value, <$RNAPasswdLabel$>.value); return true;">
		<table>
		<tr><td><$RNAUserNameLabel$> :</td><td><input type="text" name="<$RNAUserNameLabel$>"></td></tr>
		<tr><td><$RNAPasswdLabel$> :</td><td><input type="password" name="<$RNAPasswdLabel$>"></td></tr>
		<tr><td><input type="submit" value="Login"></td></tr>
		</form>
	</body>
</html>
);

# $auth = new RNA::Auth(authfile=>'.rna-passwd');
sub new {
    my $class = shift;
	my $self = {};
    
    bless $self, $class;
    
    $self->init(@_);
    
    return $self;
}


sub init {
    my $self = shift;
    my %hash = @_;

	$self->_reset;

	my $authfile = $hash{authfile};
	$self->{_authfile} = $authfile;
}


# $self->_reset
sub _reset
{
	my $self = shift;

	$self->{_account} = {};
}


# パスワードファイルに反映
#
# $bool = $self->_write;
#
sub _write
{
	my $self = shift;
	my $authfile = $self->{_authfile};
	my $account = $self->{_account};

	open (FILE, ">$authfile") || croak "Can't open $authfile\n";
	flock(FILE, 2);
	while(my ($u, $p) = each %{$account}) {
		print FILE "$u:$p\n";
	}
	flock(FILE, 8);
	close(FILE);

	return 1;
}


# パスワードファイル読み込み
#
# $bool = $self->_read;
sub _read
{
	my $self = shift;
	my $authfile = $self->{_authfile};

	# reset
	$self->_reset;

	open (FILE, $authfile) || croak "Can't open $authfile\n";
	flock(FILE, 1);
	while(<FILE>) {
		s/\r\n/\n/g;
		chomp;
		my ($username, $passwd) = split(/:/);
		$self->{_account}->{$username} = $passwd;
	}
	flock(FILE, 8);
	close(FILE);

	return 1;
}


# $salt = $self->gen_salt;
sub gen_salt
{
	my $self = shift;
	my @table = qw(a b c d e f g h i j k l m n o p q r s t u v w x y z);

	return 
		$table[int(rand(scalar(@table) - 2))] 
		. $table[int(rand(scalar(@table) - 2))];
}

# $bool = $self->check_cookie($cgi);
sub check_cookie
{
	my $self = shift;
	my $cgi = shift;

	my $username = $cgi->cookie($username_label);
	my $passwd = $cgi->cookie($passwd_label);

	return $self->check($username, $passwd);
}

# $bool = $self->check($username, $passwd);
sub check
{
	my $self = shift;
	my ($username, $passwd) = @_;

	return 0 unless($username);

	# read passwd file
	$self->_read;

	my $account = $self->{_account};

	# 該当のユーザーが存在しない
	unless(exists $account->{$username}){
		$self->_reset;
		return 0;
	}

	my $valid_passwd = $account->{$username};

	$self->_reset;
	return crypt($passwd, $valid_passwd) eq $valid_passwd;
}

# $bool = $self->add_user($username, $passwd);
sub add_user
{
	my $self = shift;
	my ($username, $passwd) = @_;

	return 0 unless($username);

	# read passwd file
	$self->_read;

	my $account = $self->{_account};

	# ユーザーが存在する
	if(exists $account->{$username}){
		return 0;
	}

	$account->{$username} = crypt($passwd, $self->gen_salt);

#print "Content-type: text/plain\n\n". join(':', %{$account});

	# write passwd file
	$self->_write;

	return 1;
}

# $bool = $self->update_user($username, $passwd);
sub update_user
{
	my $self = shift;
	my ($username, $passwd) = @_;

	return 0 unless($username);

	# read passwd file
	$self->_read;
	my $account = $self->{_account};

	# ユーザーが存在しない
	unless(exists $account->{$username}){
		return 0;
	}

	$account->{$username} = crypt($passwd, $self->gen_salt);

	# write passwd file
	$self->_write;
	return 1;
}

# $bool = $self->delete_user($username);
sub delete_user
{
	my $self = shift;
	my ($username) = @_;

	return 0 unless($username);

	# read passwd file
	$self->_read;
	my $account = $self->{_account};

	# ユーザーが存在しない
	unless(exists $account->{$username}){
		return 0;
	}

	delete $account->{$username};

	# write passwd file
	$self->_write;

	return 1;
}


# $str = $self->login_page(transfer=>$uri, template=>$template, encoding=>'UTF-8');
sub login_page
{
	my $self = shift;
	my %hash = @_;

	my $template = $hash{template} || $default_template;
	my $transfer_uri = $hash{transfer};
	my $encoding = $hash{encoding} || $default_encoding;

	my %text_hash = (
		RNAUserNameLabel=>$username_label, RNAPasswdLabel=>$passwd_label, 
		RNATransferURI=>$transfer_uri, RNAEncoding=>$encoding);

	foreach my $t (keys %text_hash){
		$template =~ s/<\$$t\$>/$text_hash{$t}/ges;
	}

	require CGI;
	my $header = CGI->new->header(-type=>'text/html', -charset => $encoding);

	return $header . $template;
}



#=============================================================================
1;
__END__

