#=============================================================================
# Copyright (C) 2003           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# ハイパーリンク，Trackback 関連のモジュール
#
# $self->{
#	timeout => 120   # HTTP アクセス時のタイムアウト [s]
#	link_info => {
#		'http://****/***.html' => $rss,
#		'http://...' => $rss2,
#		'http://...' => $rss3,
#		...
#	}
# }
# 
# '対象コンテンツのURI （たいていは HTML）' 
#	=> 'コンテンツのリンク情報を格納するRSS （RNA::RSS）'
#
#=============================================================================
package RNA::LinkInfo;

use strict;
use Jcode;
use RNA::RSS;
use RNA::Utils qw( :all );
use vars qw($VERSION);

$VERSION = '0.1';

my $default_timeout = 180;

# my $link_info = new RNA::LinkInfo(timeout=>$config->{Timeout});
sub new {
	my $class = shift;
	my $self = {};
	
	bless $self, $class;
	
	$self->init(@_);
	
	return $self;
}

sub init {
	my $self = shift;
	my %hash = @_;

	$self->{timeout} = $hash{timeout} || $default_timeout;

	$self->{link_info} = {};
}


# $link_hash_ref = $self->link_info;
sub link_info
{
	my $self = shift;
	return $self->{link_info};
}


# $self->build($items_list_ref);
#	$items_list_ref : array reference of RNA::RSS items
#
sub build
{
	my $self = shift;
	my $items_list_ref = shift;

	my @rss_array = ();
	foreach my $item (@{$items_list_ref}) {
		my $rss = new RNA::RSS;
		$rss->channel(%{$item});
		push @rss_array, $rss;
	}

	foreach my $rss (@rss_array) {
		$self->add($rss);
	}
}

# $self->add($rss);
sub add
{
	my $self = shift;
	my $rss = shift;
	my $uri = $rss->{channel}->{link};

	$rss = $self->get_link_info_rss($rss);

	#if ($rss->{items}->[0]->{link}) {
		$self->add_item(uri=>$uri, rdf=>$rss);
	#}
}

# $self->add_item(uri=>'http://***/***.html', rdf=>$rss)
sub add_item
{
	my $self = shift;
	my %hash = @_;

	my $uri = $hash{uri};
	my $rss = $hash{rdf};

	$self->{link_info}->{$uri} = $rss;
}


# $rss = $self->get_link_info_rss($rss);
#
#	RNA::RSS オブジェクトを返す
sub get_link_info_rss
{
	my $self = shift;
	my $rss = shift;
	my $uri = $rss->{channel}->{link};

	# html 文書を取得
	my ($str, $headers) = &get_html(uri=>$uri, timeout=>$self->{timeout});
	Jcode::convert(\$str, 'utf8');	# UTF-8 に変換

	#--------------------------
	# trackback 情報の取得
	#--------------------------
	if($str =~ /\<rdf:Description.*?trackback:ping=\"(.+?)\".*?\/?\s*\>/si){
		my $tb_ping_uri = $1;
		# trackback CGI から情報取得
		my ($str, $headers) = &get_html(
			uri=> $tb_ping_uri . '?__mode=rss', timeout=>$self->{timeout});
		Jcode::convert(\$str, 'utf8');	# UTF-8 に変換

		my $rss_tmp = new RNA::RSS;
		$rss_tmp->parse($str);
		$self->set_trackback_flag($rss_tmp);

		$rss->add_items(@{$rss_tmp->{items}});
	}

	#--------------------------
	# link 情報の取得
	#--------------------------
	{
#		my $target_str = $str;		# from raw html
		my $target_str = $rss->{channel}->{description};
		my $rss_tmp = new RNA::RSS;
		while($target_str =~ s/(<|&lt\;)a\s+href=("|'|&quot\;)(.+?)("|'|&quot\;).*?(>|&gt\;)(.*?)(<|&lt\;)\/a(>|&gt\;)//si){
			my $uri = $3;
			my $content = $6;
			$content = $uri if(!$content);

			$rss_tmp->add_item(title=>$content, link=>$uri);
		}
		while($target_str =~ s/((http|ftp|https):\/\/[^\s<>"]+?)(\s|&lt;|&gt;|&quot;|>|<)//si){
			my $uri = $1;
			$rss_tmp->add_item(title=>$uri, link=>$uri);
		}

		$self->set_normal_link_flag($rss_tmp);
		$rss->add_items(@{$rss_tmp->{items}});
	}
	

	return $rss;
}


# $self->export_directory($dir);
#
sub export_directory
{
	my $self = shift;
	my $dir = shift;
	my %link_info = %{$self->{link_info}};

	$dir =~ s/\/$//;

	$self->clear_directory($dir);

	my $i = 1;
	foreach my $uri (keys %link_info) {
		my $rss = $link_info{$uri};
		
		my $filename = $dir . '/links_' . sprintf("%010d", $i++) . '.rdf';
		my $str = $rss->as_string;

		&print_file($filename, \$str);
	}
}


# $self->clear_directory($dir);
sub clear_directory
{
	my $self = shift;
	my $dir = shift;

	unlink(glob($dir . '/*.rdf'));
}


# $self->import_directory($dir);
#
sub import_directory
{
	my $self = shift;
	my $dir = shift;
	my %link_info = %{$self->{link_info}};

	$dir =~ s/\/$//;

	foreach my $filename (glob($dir . '/*.rdf')) {
		my $rss = new RNA::RSS;
		$rss->parsefile($filename);

		my $uri = $rss->{channel}->{link};
		if($uri) {
			$self->add_item(uri=>$uri, rdf=>$rss);
		}
	}
}

# $self->import_object($obj);
#    $obj : LinkInfo オブジェクト
sub import_object
{
	my $self = shift;
	my $obj = shift;
	my %target_link_info  = %{$obj->{link_info}};

	while (my ($uri, $rss) = each %target_link_info) {
		$self->add_item(uri=>$uri, rdf=>$rss);
	}
}


# $self->set_trackback_flag($rss);
sub set_trackback_flag
{
	my $self = shift;
	my $rss = shift;

	foreach my $item (@{$rss->{items}}) {
		$rss->add_node($item, (semblog=>{in=>$item->{link}}));
	}
}

# $self->set_normal_link_flag($rss);
sub set_normal_link_flag
{
	my $self = shift;
	my $rss = shift;

	foreach my $item (@{$rss->{items}}) {
		$rss->add_node($item, (semblog=>{out=>$item->{link}}));
	}
}


# $self->reduce;
sub reduce
{
	my $self = shift;

	foreach my $rss (values %{$self->{link_info}}) {
		foreach my $item (@{$rss->{items}}) {
			delete $item->{description};
		}
	}
}

#==============================================================================
1;
__END__

