package RNA::OPML;
#=============================================================================
# Copyright (C) 2003           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
#
# OPML ֘ÃW[
#	http://www.opml.org/spec
#=============================================================================

use strict;
use Carp;
use XML::SAX::PurePerl;
use RNA::Utils qw( :all );
use vars qw($VERSION);

$VERSION = '0.1';

my $default_version = '1.0';
my $default_encoding = 'UTF-8';

my %opml_field = (
	head => {
		title => '',
		dateCreated => '',  # Date and Time Specification of RFC 822.
		dateModified => '', # Date and Time Specification of RFC 822.

		ownerName => '',
		ownerEmail => '',

		# comma-separated list of line numbers that are expanded. 
		# The line numbers in the list tell you which headlines to expand. 
		# The order is important. For each element in the list, X, 
		# starting at the first summit, navigate flatdown X times and expand. 
		# Repeat for each element in the list.
		expansionState => '', 

		# number, saying which line of the outline is displayed on the top line
		#  of the window. This number is calculated with the expansion state 
		# already applied
		vertScrollState => '', 

		windowTop => '', 
		windowLeft => '',
		windowBottom => '',
		windowRight => '',
	},
	body => {
		outlines => []
		# outlines => [
		#	{
		#		title => '',  # category
		#		text => '',   # category
		#		isComment => 'true', # whether commented
		#		isBreakpoint => 'false',
		#		outlines => [
		#			{	# each site
		#				type        => 'rss',
		#				text        => '', # title 
		#				title       => '', # title
		#				description => '', # description
		#				xmlUrl      => ''  # URI
		#				creator     => ''  # creator
		#			},
		#			{ ... 
		#								  }
		#		]
		#	}
		# ]
	}
);

#my $modules = {
#	'http://purl.org/rss/1.0/' => 'rss',
#};


# $bool = RNA::OPML::is_empty_value($str);
sub is_empty_value
{
	my $str = shift;

	return ($str eq '-' || !$str) ? 1 : 0;
}

# $str = RNA::OPML::empty_value;
sub empty_value
{
	return '-';
}



sub new {
    my $class = shift;
	my $self = {};
    
    bless $self, $class;
    
    $self->init(@_);
    
    return $self;
}


sub init {
    my $self = shift;
    my %hash = @_;

	%{$self} = %opml_field;
	
    # modules
    $self->{modules} = {};

    #get version info
    (exists($hash{version}))
	? ($self->{version} = $hash{version})
	    : ($self->{version} = $default_version);

    # encoding
    (exists($hash{encoding}))
	? ($self->{encoding} = $hash{encoding})
	    : ($self->{encoding} = $default_encoding);
}

#sub add_module {
#    my $self = shift;
#    my $hash = {@_};
#
#    $hash->{prefix} =~ /^[a-z_][a-z0-9.-_]*$/ or
#    croak "a namespace prefix should look like [a-z_][a-z0-9.-_]*";
#
#    $hash->{uri} or
#    croak "a URI must be provided in a namespace declaration";
#
#	  $self->{modules}->{$hash->{uri}} = $hash->{prefix};
#}



sub as_string {
    my $self = shift;
    my $version = $self->{version};
    my $encoding = $self->{encoding};
    my $output = '';

	$output .= qq(<?xml version="1.0" encoding="$encoding" ?>
<opml version="$version">
);

	#----------------------
	# head
	#----------------------
	$output .= "\t<head>\n";

	my $head = $self->{head};
	foreach my $el (keys %{$head}) {
		if($head->{$el}) {
			$output .= "\t\t<$el>" . encode($head->{$el}) . "</$el>\n";
		}
	}
	$output .= "\t</head>\n";

	#----------------------
	# body
	#----------------------
	$output .= "\t<body>\n";

	my $outlines = $self->{body}->{outlines};
	foreach my $outline (@{$outlines}) {
		$output .= $self->as_string_outline($outline);
	}
	$output .= "\t</body>\n";

	$output .= "</opml>\n";

    return $output;
}

# $str = $self->as_string_outline($outline);
sub as_string_outline {
    my $self = shift;
    my $outline = shift;

	my $output = '';
	my $attributes = '';
	my $content = '';
	foreach my $el (keys %{$outline}) {
#print STDERR $el . ' : ' . $outline->{$el} . "\n";
		my $val = $outline->{$el};
		if($el eq 'outlines') {
			# recursive
			foreach my $o (@{$val}) {
				$content .= $self->as_string_outline($o);
			}
		}
		elsif($val) {
			$attributes .= " $el=\"" . encode($val) . "\"";
		}
	}

	if($content) {
		$output .= "\t\t<outline" . $attributes . " >\n" 
			. "\t$content\n"
			. "\t\t</outline>\n";
	}
	else {
		$output .= "\t\t<outline" . $attributes . " />\n";
	}

	return $output;
}


# $rss = $self->to_rss($base_rss);
#
# 	$rss : RNA::RSS module
sub to_rss
{
	my $self = shift;
	my $rss = shift;

	#--------------------------------
	# <head>
	#--------------------------------
	my $head = $self->{head};
	my $channel = $rss->{channel};
	$channel->{title} = $head->{title} if($head->{title});
	$channel->{dc}->{creator} = $head->{ownerName} if($head->{ownerName});
	$channel->{dc}->{date} = $head->{dateModified} if($head->{dateModified});

	#--------------------------------
	# <body>
	#--------------------------------
	my $items_ref = $rss->{items};
	my $subject_array_ref = [];
	foreach my $o (@{$self->{body}->{outlines}}) {
		$self->__outline2item($o, $items_ref, $subject_array_ref);
	}

	return $rss;
}

# $self->__outline2item($o, $items_ref, $subject_array_ref);
sub __outline2item
{
	my $self = shift;
	my $outline = shift;
	my $items_ref = shift;
	my $aref = shift;
	my @subject_array = @{$aref};
	my $subject = join('/', @subject_array);

	if($outline->{xmlUrl}) {
	# xmlUrl  site
		my $item = {};
		my $title = ($outline->{title} || $outline->{text}) 
				|| RNA::OPML::empty_value;
		
		$item->{title} = $title;
		$item->{link}  = $outline->{xmlUrl};
		$item->{description} = $outline->{description};
		$item->{dc} = {};
		$item->{dc}->{creator} = $outline->{creator};
		$item->{dc}->{subject} = $subject;

		push(@{$items_ref}, $item);
	}
	else {
	# JeSisubjectj
		push(@subject_array, $outline->{title});

		foreach my $o (@{$outline->{outlines}}) {
			$self->__outline2item($o, $items_ref, \@subject_array);
		}
	}
}


# $self->parse_rss($rss)
#
# 	$rss : RNA::RSS module
sub parse_rss {
	my $self = shift;
	$self->init((%$self));
	my $rss = shift;

	$self->parse_head($rss);
	$self->parse_body($rss);
}

# $self->parse_head($rss);
sub parse_head
{
	my $self = shift;
	my $rss = shift;
	my $dc = $rss->{channel}->{dc};

	my $date = '';
	if($dc->{date}) {
		$date = &dcdate_to_rfc822($dc->{date});
	}
	
	my %hash = (
		title => $rss->{channel}->{title},
		dateModified => $date ,
		ownerName => $dc->{creator}
	);

	my $head = $self->{head};
	foreach my $el (keys %{$head}) {
		if($hash{$el}){
			$head->{$el} = $hash{$el};
		}
	}
}

# $self->parse_body($rss);
sub parse_body
{
	my $self = shift;
	my $rss = shift;

	my @items = @{$rss->{items}};
	my %subject_hash = ();
	foreach my $item (@items){
		$subject_hash{$item->{dc}->{subject}} = 1;
	}
	my @subjects = sort keys %subject_hash;

	# empty category
	foreach my $item (@items) {
		my $subject = $item->{dc}->{subject};
		if(&is_empty_value($subject)) {
			my $outline = $self->rssitem2outline($item);
			$self->add_outline(%{$outline});
		}
	}

	# categories
	foreach my $subject (@subjects) {
		# if empty then skip
		if(&is_empty_value($subject)) {next;}

		my $outline = {};
		$outline->{title} = $subject;
		$outline->{text} = $subject;
		$outline->{outlines} = [];

		foreach my $item (@items) {
			my $dc = $item->{dc};
			if($dc->{subject} ne $subject){
				next;
			}

			my $sub_outline = $self->rssitem2outline($item);

			push (@{$outline->{outlines}}, $sub_outline);
		}

		$self->add_outline(%{$outline});
	}
}

# $self->rssitem2outline($item);
sub rssitem2outline
{
	my $self = shift;
	my $item = shift;

	my $dc = $item->{dc};

	my $outline = {
		type     => 'rss',
		text     => $item->{title} ? $item->{title} : '',
		title    => $item->{title} ? $item->{title} : '',
		description => $item->{description} ? $item->{description} :'',
		xmlUrl      => $item->{link} ? $item->{link} : '',
		creator => $dc->{creator} ? $dc->{creator} : ''
	};

	return $outline;
}


sub add_outline {
    my $self = shift;
    my $hash_ref = {@_};

	push (@{$self->{body}->{outlines}}, $hash_ref);
}




# $self->parse($str)
#
sub parse {
	my $self = shift;
	$self->init((%$self));

	my $str = shift;
	my $handler = OPMLParseHandler->new(Result => $self);
	my $parser = XML::SAX::PurePerl->new(Handler => $handler);

	# for the perl version less then 5.7.2
	$str =~ s/encoding=["'].+?['"](.*?\?>)/$1/i;

	$parser->parse_string($str);
}

sub parsefile {
	my $self = shift;
	my $file = shift;
	open(IN, $file) || croak "Cannot open file $file : $!";
	my $str = "";
	while(my $s = <IN>){
		$str .= $s;
	}
	$self->parse($str);
}


sub save {
    my ($self,$file) = @_;
    open(OUT,">$file") || croak "Cannot open file $file for write: $!";
    print OUT $self->as_string;
    close OUT;
}

# $result = &RNA::OPML::encode ($text);
sub encode {
	my $text = shift;
	
    $text =~ s/</&lt;/g;
    $text =~ s/>/&gt;/g;
    $text =~ s/"/&quot;/g;

	return $text;
}

#=============================================================================

package OPMLParseHandler;

use strict;

sub new {
    my $class = shift;
    my %opts = @_;

	my $self = \%opts;
    bless $self, $class;

	$self->reset;
	return $self;
}

sub reset
{
	my $self = shift;
	$self->{ElementStack} = [];
	$self->{CurrentMode} = '';  # 'head' or 'body' or ''
	$self->{CurrentElementName} = '';
}

sub set_current_element_name
{
	my $self = shift;
	my $name = shift;

	$self->{CurrentElementName} = $name;
}

sub get_current_element_name
{
	my $self = shift;
	return $self->{CurrentElementName};
}


# $self->set_mode($mode);
sub set_mode
{
	my $self = shift;
	my $mode = shift;
	$self->{CurrentMode} = $mode;
}

sub get_mode
{
	my $self = shift;
	return $self->{CurrentMode};
}

# $self->push_stack($elment);
sub push_stack
{
	my $self = shift;
	my $element = shift;	# reference or element_name

	push(@{$self->{ElementStack}}, $element);
}

# $elment = $self->pop_stack;
sub pop_stack
{
	my $self = shift;
	return pop @{$self->{ElementStack}};
}

# $elment_ref = $self->end_of_stack;
sub end_of_stack
{
	my $self = shift;
	return $self->{ElementStack}->[-1];
}

# DocumentHandler
sub set_document_locator {
    my $self = shift;
# 	print "set_document_locator\n";
}

sub start_document {
    my $self = shift;
#    print "start_document\n";    
	$self->reset;
}

sub end_document {
    my $self = shift;
#    print "end_document\n";

    my $result = $self->{Result};
    $result->{head} = $self->{head};
    $result->{body} = $self->{body};
}

sub start_element {
    my $self = shift;
#    print "start_element\n";
	my $el = shift;

	my $element_name = $el->{LocalName};

	# set current element name 
	$self->set_current_element_name($element_name);

	# set mode
	if($element_name eq 'head' || $element_name eq 'body') {
		$self->set_mode($element_name);
	}

	# element
	my $element = {};
	my $parent = $self->end_of_stack();
	if($self->get_mode eq 'head') {
		if($element_name eq 'head') {
		# <head>
			$parent->{$element_name} = {};
		}
		else {
		# <head><tag></tag></head>
			$parent->{$element_name} = '';
		}
		$element = $parent->{$element_name};
	}
	elsif($self->get_mode eq 'body') {
		if($element_name eq 'body') {
		# <body>
			$parent->{$element_name} = {};
			$element = $parent->{$element_name};
		}
		elsif($element_name eq 'outline') {
		# <outline> element
			unless($parent->{outlines}) {
				$parent->{outlines} = [];
			}

			foreach my $attr (values %{$el->{Attributes}}) {
				my $name = $attr->{LocalName};
				my $value = $attr->{Value};

#				print "$name : $value\n";
				$element->{$name} = $value;
			}
			push(@{$parent->{outlines}}, $element);
		}
		else {
		}
	}
	else {
	}

	# push stack
	if($self->get_mode eq 'head') {
		$self->push_stack($element);
	}
	elsif($self->get_mode eq 'body') {
		$self->push_stack($element);
	}
	else {
		if($element_name eq 'opml') {
			$self->push_stack($self);
		}
		else{
			$self->push_stack($element);
		}
	}

#	print $el->{Name} . ' : ' . $self->get_mode . "\n";

#	print join(', ', keys %{$_[0]});
#	print "\n";
#	print join(', ', values %{$_[0]});
#	print "\n";
#	print join(',' , keys %{$_[0]{Attributes}});
#	print "\n";
#	print map {join(',', keys %{$_}). "\n"} values %{$_[0]{Attributes}};
#	print "\n";
#	print "\n";
}

sub end_element {
    my $self = shift;
#    print "end_element\n";
	my $el = shift;

	my $element_name = $el->{LocalName};

	# clear current element name 
	$self->set_current_element_name('');

	# clear mode
	if($element_name eq 'head' || $element_name eq 'body') {
		$self->set_mode('');
	}

#	print $el->{Name} . ' : ' . $self->get_mode . "\n";
	# pop stack
	my $pop_el = $self->pop_stack;
}

sub characters {
    my $self = shift;
    my $node  = shift;
    my $str = $node->{Data}; 
#   warn "Char: ", $node->{Data}, "\n";
#   print "characters\n";

	if ($str =~ /^\s+$/) {
		return;
	}

	my $element_name = $self->get_current_element_name;
	unless($element_name) {
		return;
	}
#print "<$element_name> : '$str'\n";
	if($self->get_mode eq 'head') {
		$self->{head}->{$element_name} = $str;
	}
}

sub processing_instruction {
    my $self = shift;
#    print "processing_instruction\n";
}

sub ignorable_whitespace {
    my $self = shift;
#    print "ignorable_whitespace\n";
}

# LexHandler
sub comment {
    my $self = shift;
#    print "comment\n";
}

# DTDHandler
sub notation_decl {
    my $self = shift;
#    print "notation_decl\n";
}

sub unparsed_entity_decl {
    my $self = shift;
#    print "entity_decl\n";
}

# EntityResolver
sub resolve_entity {
    my $self = shift;
#    print "resolve_entity\n";
    return '';
}




#=============================================================================
1;
__END__

