#=============================================================================
# Copyright (C) 2003           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# WebEdit Utility of RSS 
#
#==============================================================================
package RNA::RSS::WebEdit;

use strict;
use RNA::RSS;
use RNA::Utils qw( :all );
use vars qw($VERSION);
$VERSION = '0.1';

# $err_msg = &RNA::RSS::WebEdit::update_rss($rss, $arg_hash_ref, $order)
#	$order : 'date' , 'front', 'back'
#
sub update_rss
{
	my $rss = shift;
	my $arg_ref = shift;
	my $order = shift || 'back';
	my %arg = %{$arg_ref};

	# 対象の <item> があるかどうか
	my %exist_hash = ();
	foreach my $item (@{$rss->{items}}){
		#$exist_hash{$item->{link}} = 1;
		$exist_hash{escape_uri($item->{link})} = 1;
	}

	if ($arg{action} =~ /delete/i){
		# delete
		# リストに無い場合，削除できない
		unless($exist_hash{escape_uri($arg{link})}){
			return $arg{link} .q( : can't be removed. It's not in the list.);
		}

		my @new_items = ();
		foreach my $item (@{$rss->{items}}){
			my $link = $item->{link};
			if(escape_uri($link) ne escape_uri($arg{link})){
				push(@new_items, $item);
			}
		}
		$rss->{items} = \@new_items;
	}
	elsif($arg{action} =~ /add/i){
		# add
		# すでにある場合は，追加しない
		if($exist_hash{escape_uri($arg{link})}){
			return $arg{link} . q( : can't be added. It's already in the list);
		}

		my $new_item = {
				title       => encode($arg{title}),
				link        => $arg{link},
				description => encode($arg{description}),
				dc => {
					subject => encode($arg{subject}),
					creator => encode($arg{creator}),
					date => encode($arg{date})
				},
				ag => {
					source => encode($arg{source}),
					sourceURL => $arg{sourceURL}
				}
			};

		# 追加処理
		if($order eq 'front') {
			unshift (@{$rss->{items}}, $new_item);
		}
		elsif($order eq 'date') {
			unshift (@{$rss->{items}}, $new_item);
			$rss->sort;
		}
		else {	# back
			push (@{$rss->{items}}, $new_item);
		}
	}
	elsif($arg{action} =~ /update/i){
		# update
		# リストに無い場合，更新できない
		unless($exist_hash{escape_uri($arg{select})}){
			return $arg{select} .q( : can't be updated. It's not in the list.);
		}

		foreach my $item (@{$rss->{items}}){
			if(escape_uri($item->{link}) eq escape_uri($arg{select})
				#||$item->{link} eq $arg{select} 
			){
				#更新
				%{$item} = (
					title       => encode($arg{title}),
					link        => $arg{link},
					description => encode($arg{description}),
					dc => {
						subject => encode($arg{subject}),
				 		creator => encode($arg{creator}),
						date => encode($arg{date})
				  	},
					ag =>{
						source => encode($arg{source}),
						sourceURL => $arg{sourceURL}
				  	}
				);

				last;
			}
		}
	}
	else{
		 return $arg{action} . q( : invalid action.);
	}


	return '';
}



# $str = &RNA::RSS::WebEdit::show_configure_page($rss, $template, $hash_ref)
sub show_configure_page
{
	my $rss = shift;
	my $template = shift;
	my $text_hash_ref = shift;
	my %text_hash = %{$text_hash_ref};
	my @items = @{$rss->{items}};

	# duplicated URI
	my @dup_list = &get_duplicated_uri((map {$_->{link}} @items));
	my $dup_check = join('|', @dup_list);

	# subject のリスト
	my %subject_hash = get_subject_list(@items);
	my $subject_select_options = '';
	foreach my $s (sort keys %subject_hash) {
		my $n = $subject_hash{$s};
		$subject_select_options .= "<option value=\"" . encode($s) . "\">" 
			. encode($s) . " ($n)</option>\n";
	}

	require CGI;
	my $http_header =
		CGI->new->header(-type=>'text/html',
			-charset => $rss->{encoding});

	my $indent = "\t\t";
	my $update_rss_switch = join("\n$indent",
		map {
			"case \"" . escape_uri($_->{link}) . "\" : \n"
			. "$indent\tform.title.value = \"". encode($_->{title}) . "\"\;\n"
			. "$indent\tform.link.value = \"". escape_uri($_->{link}) . "\"\;\n"
			. "$indent\tform.description.value = \"" . encode($_->{description}) . "\"\;\n"
		    . "$indent\tform.creator.value = \"". encode($_->{dc}->{creator}) . "\"\;\n"
		    . "$indent\tform.subject.value = \"". encode($_->{dc}->{subject}) . "\"\;\n"
			. "$indent\tform.source.value = \"". encode($_->{ag}->{source}) . "\"\;\n"
			. "$indent\tform.sourceURL.value = \"". escape_uri($_->{ag}->{sourceURL}) . "\"\;\n"
			. "$indent\tform.date.value = \"". encode($_->{dc}->{date}) . "\"\;\n"
			. "$indent\t" 
				.($dup_check && $_->{link}=~/$dup_check/?"alert('Duplicated entry! Modify $rss->{channel}->{link} directly');":'')
				. "\n"
			. "$indent\tbreak\;"
		} @items
	);

	$indent = "\t\t";
	my $update_rss_options = "\n";
	foreach my $i (0 .. $#items) {
		my $item = $items[$i];
		
		$update_rss_options .= "$indent" 
			. sprintf("<option value=\"%s\">%04d. %s \&nbsp\;\&nbsp\; : %s</option>\n", escape_uri($item->{link}), $i+1, escape_uri($item->{link}), encode($item->{title}));
	}

	#-------------------------
	# テンプレート
	#-------------------------
	$text_hash{__RNAUpdateRSSSwitch__} = $update_rss_switch;
	$text_hash{__RNAUpdateRSSOptions__}  = $update_rss_options;
	$text_hash{__RNASubjectSelectOptions__} = $subject_select_options;

	foreach my $t (keys %text_hash){
		$template =~ s/\<\$$t\$\>/$text_hash{$t}/ges;
	}

	return $http_header . $template;
}


# @duplicated_uri_list = &RNA::RSS::WebEdit::get_duplicated_uri(@uri_list)
sub get_duplicated_uri
{
	my @uri_list = @_;

	my %count =();
	foreach my $uri (@uri_list) {
		$count{$uri} += 1;
	}

	my @ret = ();
	foreach my $uri (keys %count) {
		if($count{$uri} > 1) {
		# duplicated entry
			push(@ret, $uri);
		}
	}

	return @ret;
}

# 	my %subject_hash = RNA::RSS::WebEdit::get_subject_list(@items);
#
# %subject_hash = ('sub1' => 4)
sub get_subject_list
{
	my @items = @_;
	
	my %hash = ();
	foreach my $item (@items) {
		my $subject = $item->{dc}->{subject};
		#if(!$config->is_empty_content($subject)){
			$hash{$subject} += 1;
		#}
	}
	return %hash;
}


# $str = RNA::RSS::WebEdit::escape_uri($str)
sub escape_uri
{
	my $str = shift;
	$str = html_decode($str);
	$str =~ s/[<>]//g;
	$str =~ s/"//g;
	return $str;
}

# $str = RNA::RSS::WebEdit::encode($str);
sub encode
{
	my $str = shift;

	my $encoded = '';
	while ($str =~ s/(.*?)(<\!\[CDATA\[.*?\]\]>)//s) {
		$encoded .= html_encode2($1) . $2;
	}
	$encoded .= html_encode2($str);

	return $encoded;
}


#=============================================================================
1;

