#=============================================================================
# Copyright (C) 2003           Ikki Ohmukai,      All rights reserved.
#
#
# This file is part of RNA.
#
#    RNA is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RNA is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RNA; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#=============================================================================
# XML-RPC 
#
#  !! Do not  'use' or 'require' the modules that access STDIN such as 'CGI.pm'
#	【注意】標準入力にアクセスするような処理を行わないこと
#
#  http://www.xmlrpc.com/weblogsCom	: Weblogs.Com XML-RPC interface
#  http://www.xmlrpc.com/  : XML-RPC Home Page
#  http://search.cpan.org/author/KULCHENKO/SOAP-Lite-0.55/lib/XMLRPC/Lite.pm
#    XMLRPC::Lite
#
#==============================================================================


package RNA::XMLRPC;
use strict;

use vars qw($VERSION);
use XMLRPC::Transport::HTTP;

$VERSION = '0.1';

my @dispatch_list = ('weblogUpdates', 'rna');
my $config_file = ''; # './config.pl'

# &RNA::XMLRPC::set_config_file($filename);
sub set_config_file
{
	$config_file = shift;
}


# $handle = RNA::XMLRPC::server_handle;
sub server_handle
{
	# サーバーに，パッケージを dispatch 
	return XMLRPC::Transport::HTTP::CGI->dispatch_to(@dispatch_list)->handle;
}

sub load_module
{
	require RNA;
	require Jcode;
	require RNA::Utils;
	require RNA::RSS;
	require RNA::RSS::WebEdit;
	require RNA::AntennaTree;

	return RNA->new(Config => $config_file);
}

#=============================================================================
package weblogUpdates;
use strict;

# $hash_ref = &ping($blog_name, $blog_uri)
#
# MT からの自動 ping の受付
#
# Usage :
#POST /~msano/rna/rna-xmlrpc.cgi HTTP/1.0
#User-Agent: RNA
#Host: www-kasm.nii.ac.jp
#Content-Type: text/xml
#Content-length: 206
#
#<?xml version="1.0"?><methodCall><methodName>weblogUpdates.ping</methodName><params><param><value>Scripting News</value></param><param><value>http://www.scripting.com/</value></param></params></methodCall>
#
sub ping
{
	shift if UNIVERSAL::isa($_[0] => __PACKAGE__);
	my ($blog_name, $blog_uri) = @_;

	my $rna = &RNA::XMLRPC::load_module;
	$rna->update;

	return {
		flerror => SOAP::Data->type('boolean'=>0), 
		message => 'Thanks for the ping'};
}


#=============================================================================
package rna;
use strict;

#[Request]
#POST /~msano/rna/rna-xmlrpc2.cgi HTTP/1.0
#User-Agent: Radio UserLand/7.1b7 (WinNT)
#Host: www-kasm.nii.ac.jp
#Content-Type: text/xml
#Content-length: 709
#
#<?xml version="1.0" encoding="UTF-8"?><methodCall><methodName>rna.addClip</methodName><params><param><value><struct><member><name>title</name><value>XML-RPC Title</value></member><member><name>link</name><value>XML-RPC Link</value></member><member><name>description</name><value>XML-RPC Description</value></member><member><name>subject</name><value>XML-RPC DC Category</value></member><member><name>creator</name><value>XML-RPC DC creator</value></member><member><name>date</name><value>XML-RPC DC Date</value></member><member><name>source</name><value>XML-RPC AG source</value></member><member><name>sourceURL</name><value>XML-RPC AG SourceURL</value></member></struct></value></param></params></methodCall>
#
#[Response]
#HTTP/1.1 200 OK
#Date: Sun, 31 Aug 2003 04:03:07 GMT
#Server: Apache/1.3.26 (Unix) Debian GNU/Linux PHP/4.1.2 mod_jk/1.1.0 DAV/1.0.3
#SOAPServer: SOAP::Lite/Perl/0.
#Content-Length: 279
#Connection: close
#Content-Type: text/xml
#
#<?xml version="1.0" encoding="UTF-8"?><methodResponse><params><param><value><struct><member><name>error</name><value><boolean>0</boolean></value></member><member><name>message</name><value><string>Done.</string></value></member></struct></value></param></params></methodResponse>
#
#[Fault Response]
#HTTP/1.1 200 OK
#Date: Sun, 31 Aug 2003 04:04:08 GMT
#Server: Apache/1.3.26 (Unix) Debian GNU/Linux PHP/4.1.2 mod_jk/1.1.0 DAV/1.0.3
#SOAPServer: SOAP::Lite/Perl/0.
#Content-Length: 329
#Connection: close
#Content-Type: text/xml
#
#<?xml version="1.0" encoding="UTF-8"?><methodResponse><params><param><value><struct><member><name>error</name><value><boolean>1</boolean></value></member><member><name>message</name><value><string>XML-RPC Link : can't be added. It's already in the list</string></value></member></struct></value></param></params></methodResponse>
#
sub addClip
{
	shift if UNIVERSAL::isa($_[0] => __PACKAGE__);
	my $rna = &RNA::XMLRPC::load_module;
	my $config = $rna->{Config};
	my $clip_rss_file = $config->{ClipList}->{RSS};

	my $arg_ref = shift;
	my %arg = %{$arg_ref};
	$arg{action} = 'Add';
	$arg{select} = $arg{link};

	foreach my $k (keys %arg) {
		Jcode::convert(\$arg{$k}, 'utf8');	# UTF-8
#		print "$k : $arg{$k}\n";
	}

	# リストの取り出し
	my $rss = new RNA::RSS;
	$rss->parsefile($clip_rss_file);

	my $err_msg = &RNA::RSS::WebEdit::update_rss($rss, \%arg, 'front');
	if($err_msg) {
	# Error
		return {error => SOAP::Data->type('boolean'=>1), message => $err_msg};
	}
	else {
	# print file
		my $str = $rss->as_string;
		&RNA::Utils::print_file($clip_rss_file, \$str);

		my $template = RNA::Utils::read_file($config->{Template}->{ClipList});
		my $str_ref = RNA::AntennaTree::apply_template_to_rss($rss, 
			$template, $config->{Template}->{Element});
		RNA::Utils::print_file($config->{ClipList}->{HTML}, $str_ref);

		return {error => SOAP::Data->type('boolean'=>0), 
			message => 'Done.'};
	}
}


#=============================================================================
1;

